@@ -35,4 +35,4 @@ timeFrom :: (HasTime t s) => t -> Wire s e m a t
 timeFrom t' =
     mkSF $ \ds _ ->
         let t = t' + dtime ds
-        in t `seq` (t, timeFrom t)
+        in lstrict (t, timeFrom t)
